@@ -1,16 +1,16 @@
 package Sisimai::Lhost::FML;
 use parent 'Sisimai::Lhost';
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
-sub description { 'fml mailing list server/manager' };
+sub description { 'fml mailing list server/manager: https://www.fml.org/' };
 sub inquire {
     # Detect an error from fml mailing list server/manager
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.22.3
     my $class = shift;
     my $mhead = shift // return undef;
@@ -52,10 +52,9 @@ sub inquire {
         'securityerror' => ['Security alert:'],
     };
 
-    my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
+    my $dscontents = [__PACKAGE__->DELIVERYSTATUS]; my $v = undef;
     my $emailparts = Sisimai::RFC5322->part($mbody, $boundaries);
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
-    my $v = undef;
 
     for my $e ( split("\n", $emailparts->[0]) ) {
         # Read error messages and delivery status lines from the head of the email to the previous
@@ -104,7 +103,7 @@ sub inquire {
             last;
         }
     }
-    return { 'ds' => $dscontents, 'rfc822' => $emailparts->[1] };
+    return {"ds" => $dscontents, "rfc822" => $emailparts->[1]};
 }
 
 1;
@@ -114,7 +113,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::FML - bounce mail parser class for FML (fml.org).
+Sisimai::Lhost::FML - bounce mail decoder class for FML L<https://www.fml.org/>.
 
 =head1 SYNOPSIS
 
@@ -122,8 +121,8 @@ Sisimai::Lhost::FML - bounce mail parser class for FML (fml.org).
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::FML parses a bounce email which created by C<fml mailing list server/manager>.
-Methods in the module are called from only Sisimai::Message.
+C<Sisimai::Lhost::FML> decodes a bounce email which created by fml mailing list server/manager
+L<https://www.fml.org/>. Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -135,8 +134,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
@@ -144,7 +143,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2017-2021,2023 azumakuniyuki, All rights reserved.
+Copyright (C) 2017-2021,2023-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
