@@ -16,6 +16,7 @@ sub inquire {
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
 
+    return undef unless  index($$mbody, "Google Groups") > -1;
     return undef unless rindex($mhead->{'from'}, '<mailer-daemon@googlemail.com>')  > -1;
     return undef unless  index($mhead->{'subject'}, 'Delivery Status Notification') > -1;
     return undef unless exists $mhead->{'x-failed-recipients'};
@@ -38,27 +39,25 @@ sub inquire {
     # Thanks,
     #
     # Google Groups
-    state $indicators = __PACKAGE__->INDICATORS;
-    state $boundaries = ['----- Original message -----'];
-
-    my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
+    state $boundaries = ['----- Original message -----', 'Content-Type: message/rfc822'];
+    my $dscontents = [__PACKAGE__->DELIVERYSTATUS]; my $v = $dscontents->[-1];
     my $emailparts = Sisimai::RFC5322->part($mbody, $boundaries);
-    my $recordwide = { 'rhost' => '', 'reason' => '', 'diagnosis' => '' };
     my $recipients = 0;
-    my $v = $dscontents->[-1];
+    my @entiremesg = split(/\n\n/, $emailparts->[0], 5); pop @entiremesg;
+    my $issuedcode = join(' ', @entiremesg); $issuedcode =~ y/\n/ /;
+    my $receivedby = $mhead->{'received'} || [];
+    my $recordwide = {
+        'rhost'     => Sisimai::RFC5322->received($receivedby->[0])->[1],
+        'reason'    => 'onhold',
+        'diagnosis' => Sisimai::String->sweep($issuedcode),
+    };
 
     # * You might have spelled or formatted the group name incorrectly.
     # * The owner of the group may have removed this group.
     # * You may need to join the group before receiving permission to post.
     # * This group may not be open to posting.
     my $fewdetails = [$emailparts->[0] =~ /^[ ]?[*][ ]?/gm] || [];
-    $recordwide->{'reason'} = scalar @$fewdetails == 4 ? 'rejected' : 'onhold';
-
-    my @entiremesg = split(/\n\n/, $emailparts->[0], 5); pop @entiremesg;
-    my $issuedcode = join(' ', @entiremesg); $issuedcode =~ y/\n/ /;
-    my $receivedby = $mhead->{'received'} || [];
-    $recordwide->{'diagnosis'} = Sisimai::String->sweep($issuedcode);
-    $recordwide->{'rhost'}     = Sisimai::RFC5322->received($receivedby->[0])->[1];
+    $recordwide->{'reason'} = 'rejected' if scalar @$fewdetails == 4;
 
     for my $e ( split(',', $mhead->{'x-failed-recipients'}) ) {
         # X-Failed-Recipients: neko@example.jp, nyaan@example.org, ...
@@ -74,7 +73,7 @@ sub inquire {
         $v->{ $_ } = $recordwide->{ $_ } for keys %$recordwide;
     }
     return undef unless $recipients;
-    return { 'ds' => $dscontents, 'rfc822' => $emailparts->[1] };
+    return {"ds" => $dscontents, "rfc822" => $emailparts->[1]};
 }
 
 1;
@@ -114,7 +113,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2020-2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2020-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
