@@ -12,7 +12,7 @@ sub match {
     #                           1: Matched
     # @since v4.0.0
     my $class = shift;
-    my $argv1 = shift // return undef;
+    my $argv1 = shift // return 0;
 
     state $index = [
         'duplicate header',
@@ -36,7 +36,7 @@ sub true {
     #                                   0: is not content error
     # @see      http://www.ietf.org/rfc/rfc2822.txt
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argvs = shift // return 0;
 
     require Sisimai::Reason::SpamDetected;
     return 1 if $argvs->{'reason'} eq 'contenterror';
@@ -108,7 +108,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018,2021,2022,2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018,2021,2022,2024,2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
