@@ -13,7 +13,7 @@ sub match {
     #                           1: Matched
     # @since v4.0.0
     my $class = shift;
-    my $argv1 = shift // return undef;
+    my $argv1 = shift // return 0;
 
     state $index = [
         'account not subscribed to ses',
@@ -48,7 +48,7 @@ sub true {
     # @return   [Integer]               1: is security error
     #                                   0: is not security error
     # @see http://www.ietf.org/rfc/rfc2822.txt
-    return undef;
+    return 0;
 }
 
 1;
@@ -106,7 +106,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2018,2020,2021,2023,2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018,2020,2021,2023-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
