@@ -5,7 +5,7 @@ use warnings;
 
 state $RhostClass = {
     "Aol"         => [".mail.aol.com", ".mx.aol.com"],
-    "Apple"       => [".mail.icloud.com", ".apple.com", ".me.com"],
+    "Apple"       => [".mail.icloud.com", ".apple.com", ".me.com", "privaterelay.appleid.com"],
     "Cloudflare"  => [".mx.cloudflare.net"],
     "Cox"         => ["cox.net"],
     "Facebook"    => [".facebook.com"],
