@@ -35,9 +35,7 @@ sub is_8bit {
     # @return   [Integer]       0: ASCII Characters only
     #                           1: Including 8-bit character
     my $class = shift;
-    my $argv1 = shift // return undef;
-
-    return undef unless ref $argv1 eq 'SCALAR';
+    my $argv1 = shift // return 0; return 0 if ref $argv1 ne 'SCALAR';
     return 1 unless $$argv1 =~ /\A[\x00-\x7f]+\z/;
     return 0;
 }
@@ -49,7 +47,7 @@ sub sweep {
     # @example  Clean up text
     #   sweep('  neko ') #=> 'neko'
     my $class = shift;
-    my $argv1 = shift // return undef;
+    my $argv1 = shift // return "";
 
     chomp $argv1;
     y/ //s, s/\A //g, s/ \z//g, s/ [-]{2,}[^ ].+\z// for $argv1;
@@ -63,8 +61,8 @@ sub aligned {
     # @return   [Bool]          0, 1
     # @since v5.0.0
     my $class = shift;
-    my $argv1 = shift || return undef; return undef unless length $$argv1;
-    my $argv2 = shift || return undef; return undef unless scalar @$argv2;
+    my $argv1 = shift || return 0; return 0 unless length $$argv1;
+    my $argv2 = shift || return 0; return 0 unless scalar @$argv2;
     my $align = -1;
     my $right =  0;
 
@@ -80,60 +78,16 @@ sub aligned {
     return 0;
 }
 
-sub ipv4 {
-    # Find an IPv4 address from the given string
-    # @param    [String] argv1  String including an IPv4 address
-    # @return   [Array]         List of IPv4 addresses
-    # @since v5.0.0
-    my $class = shift;
-    my $argv0 = shift || return undef; return [] if length $argv0 < 7;
-    my $ipv4a = [];
-
-    for my $e ( '(', ')', '[', ']' ) {
-        # Rewrite: "mx.example.jp[192.0.2.1]" => "mx.example.jp 192.0.2.1"
-        my $p0 = index($argv0, $e); next if $p0 < 0;
-        substr($argv0, $p0, 1, ' ');
-    }
-
-    IP4A: for my $e ( split(' ', $argv0) ) {
-        # Find string including an IPv4 address
-        next if index($e, '.') == -1;   # IPv4 address must include "." character
-
-        my $lx = length $e; next if $lx < 7 || $lx > 17; # 0.0.0.0 = 7, [255.255.255.255] = 17
-        my $cu = 0;     # Cursor for seeking each octet of an IPv4 address
-        my $as = '';    # ASCII Code of each character
-        my $eo = '';    # Buffer of each octet of IPv4 Address
-
-        while( $cu < $lx ) {
-            # Check whether each character is a number or "." or not
-            $as = ord substr($e, $cu++, 1);
-            if( $as < 48 || $as > 57 ) {
-                # The character is not a number(0-9)
-                next IP4A if     $as != 46; # The character is not "."
-                next      if     $eo eq ''; # The current buffer is empty
-                next IP4A if int $eo > 255; # The current buffer is greater than 255
-                $eo = '';
-                next;
-            }
-            $eo .= chr $as;
-            next IP4A if int $eo > 255;
-        }
-        push @$ipv4a, $e;
-    }
-    return $ipv4a;
-}
-
 sub to_plain {
     # Convert given HTML text to plain text
     # @param    [Scalar]  argv1 HTML text(reference to string)
     # @param    [Integer] loose Loose check flag
     # @return   [Scalar]        Plain text(reference to string)
     my $class = shift;
-    my $argv1 = shift // return \'';
+    my $argv1 = shift // return undef; return undef if ref $argv1 ne 'SCALAR';
     my $loose = shift // 0;
-    return \'' unless ref $argv1 eq 'SCALAR';
-
     my $plain = $$argv1;
+
     state $match = {
         'html' => qr|<html[ >].+?</html>|sim,
         'body' => qr|<head>.+</head>.*<body[ >].+</body>|sim,
@@ -171,13 +125,13 @@ sub to_utf8 {
     # @param    [String] argv2  Encoding name before converting
     # @return   [String]        UTF-8 Encoded string
     my $class = shift;
-    my $argv1 = shift || return \'';
+    my $argv1 = shift || return "";
     my $argv2 = shift;
 
     state $dontencode = ['utf8', 'utf-8', 'us-ascii', 'ascii'];
     my $tobeutf8ed = $$argv1;
     my $encodefrom = lc $argv2 || '';
-    my $hasencoded = undef;
+    my $hasencoded = 0;
     my $hasguessed = Encode::Guess->guess($tobeutf8ed);
     my $encodingto = ref $hasguessed ? lc($hasguessed->name) : '';
 
@@ -251,7 +205,7 @@ and the envelope recipient address.
 C<is_8bit()> method checks the argument include any 8bit character or not.
 
     print Sisimai::String->is_8bit(\'cat');  # 0;
-    print Sisimai::String->is_8bit(\'ねこ'); # 1;
+    print Sisimai::String->is_8bit(\'ね); # 1;
 
 =head2 C<B<sweep(I<String>)>>
 
@@ -267,13 +221,6 @@ C<aligned> method checks if each element of the 2nd argument is aligned in the 1
     print Sisimai::String->aligned(\$v, [' <', '@', 'rfc822']);      # 0
     print Sisimai::String->aligned(\$v, ['example', '@', 'neko']);   # 0
 
-=head2 C<B<ipv4(I<String>)>>
-
-C<ipv4> method return all the IPv4 address found in the given string.
-
-    my $v = "connection refused from 192.0.2.1, DNSBL returned 127.0.0.2";
-    my $p = Sisimai::String->ipv4($v); # ["192.0.2.1", "127.0.0.2"]
-
 =head2 C<B<to_plain(I<Reference to String>, [I<Loose Check>])>>
 
 C<to_plain> method converts given string as an HTML to the plain text.
@@ -294,7 +241,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018,2019,2021-2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018,2019,2021-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
